@@ -14,9 +14,18 @@
 #' @return A trimmed version of \code{dat}, reduced only to those components
 #' lying within the bounding polygon.
 #'
+#' @note It will generally be necessary to pre-load the \pkg{sf} package for
+#' this function to work correctly.
+#'
 #' @export
 trim_osmdata <- function (dat, bb_poly, exclude = TRUE)
 {
+    is_sf_loaded ()
+    if (is.list (bb_poly) & length (bb_poly) > 1)
+    {
+        message ("bb_poly has more than one polygon; the first will be selected.")
+        bb_poly <- bb_poly [[1]]
+    }
     if (nrow (bb_poly) > 2)
     {
         dat <- trim_to_poly_pts (dat, bb_poly, exclude = exclude) %>%
@@ -26,6 +35,13 @@ trim_osmdata <- function (dat, bb_poly, exclude = TRUE)
     return (dat)
 }
 
+is_sf_loaded <- function ()
+{
+    if (!any (grepl ("package:sf", search ())))
+        message ("It is generally necessary to pre-load the sf package ",
+                 "for this function to work correctly")
+}
+
 trim_to_poly_pts <- function (dat, bb_poly, exclude = TRUE)
 {
     if (is (dat$osm_points, 'sf'))
@@ -87,9 +103,15 @@ trim_to_poly <- function (dat, bb_poly, exclude = TRUE)
             {
                 indx <- get_trim_indx (dat [[g]]$geometry, bb_poly,
                                        exclude = exclude)
-                cl <- class (dat [[g]]$geometry)
+                #cl <- class (dat [[g]]$geometry) # TODO: Delete
+                attrs <- attributes (dat [[g]])
+                attrs$row.names <- attrs$row.names [indx]
+                attrs_g <- attributes (dat [[g]]$geometry)
+                attrs_g$names <- attrs_g$names [indx]
                 dat [[g]] <- dat [[g]] [indx, ] # this strips sf class defs
-                class (dat [[g]]$geometry) <- cl
+                #class (dat [[g]]$geometry) <- cl # TODO: Delete
+                attributes (dat [[g]]) <- attrs
+                attributes (dat [[g]]$geometry) <- attrs_g
             }
         }
     }
@@ -122,9 +144,15 @@ trim_to_poly_multi <- function (dat, bb_poly, exclude = TRUE)
                 else
                     indx <- which (ilens > 0)
 
-                cl <- class (dat [[g]]$geometry)
+                #cl <- class (dat [[g]]$geometry) # TODO: Delete
+                attrs <- attributes (dat [[g]])
+                attrs$row.names <- attrs$row.names [indx]
+                attrs_g <- attributes (dat [[g]]$geometry)
+                attrs_g$names <- attrs_g$names [indx]
                 dat [[g]] <- dat [[g]] [indx, ]
-                class (dat [[g]]$geometry) <- cl
+                #class (dat [[g]]$geometry) <- cl # TODO: Delete
+                attributes (dat [[g]]) <- attrs
+                attributes (dat [[g]]$geometry) <- attrs_g
             }
         }
     }
