@@ -2,8 +2,8 @@ has_internet <- curl::has_internet ()
 
 # test_all used to switch off tests on CRAN
 test_all <- (identical (Sys.getenv ("MPADGE_LOCAL"), "true") |
-             identical (Sys.getenv ("TRAVIS"), "true") |
-             identical (Sys.getenv ("APPVEYOR"), "True"))
+             identical (Sys.getenv ("TRAVIS"), "true"))
+             #identical (Sys.getenv ("APPVEYOR"), "True"))
 
 source ("../stub.R")
 
